@@ -11,7 +11,7 @@ use URI::Escape;
 use WWW::Deezer::SearchResult;
 use WWW::Deezer::Artist;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $API_VERSION = '2.0';
 
 sub new {
@@ -75,7 +75,7 @@ sub search { # http://developers.deezer.com/api/search
     my ($q, $order, $index);
 
     if (_is_hashref ($p)) {
-        $q = $p->{q};
+        $q = _to_string( $p->{q} );
         $order = $p->{order} || 'RANKING';
         $index = $p->{index} || 0;
     }
@@ -106,8 +106,11 @@ sub _get_url {
     my $url = $p->{url} || return $self->_error('No URL given');
     my $method = $p->{method} || 'GET';
 
-    my $res = $self->{ua}->request (HTTP::Request->new(
-        $method => $self->{baseurl}.$url));
+    my $request = HTTP::Request->new(
+        $method => $self->{baseurl}.$url,
+    );
+
+    my $res = $self->{ua}->request( $request );
     
     return $res->is_success ? $res->content : $self->_error($res->status_line);
 }
@@ -124,6 +127,18 @@ sub _is_hashref {
     return ref $x && ref $x eq ref {};
 }
 
+sub _to_string {
+    my ($q) = @_;
+	return $q unless ref($q);
+
+    if (_is_hashref($q)) {
+        my $res = join(" ", map { "$_:\"$q->{$_}\"" } keys %$q);
+        return $res;
+    }
+
+    return '';
+}
+
 1;
 __END__
 =head1 NAME
@@ -137,6 +152,7 @@ WWW::Deezer - Perl interface to Deezer API
   my $deezer = WWW::Deezer->new();
   my $rs1 = $deezer->search ('Spinal Tap');
   my $rs2 = $deezer->search ({ q => 'Antonio Vivaldi Concerto No. 4', order => 'RATING_DESC' });
+  my $rs3 = $deezer->search ({ q => { artist => 'Metallica', album => 'Garage Inc.' } });
 
   while (my $record = $rs1->next) {
       $album_obj = $record->album;
@@ -145,7 +161,7 @@ WWW::Deezer - Perl interface to Deezer API
 
       warn ("$name has a radio channel!") if $artist->radio;
 
-      $fans_count = $artist->nb_fans;
+      $fans_count = $artist->nb_fan;
   }
 
   my $top_record = $rs2->first;
@@ -164,7 +180,7 @@ None by default.
 =head1 SEE ALSO
 
 Oficial Deezer API documentation:
-http://developers.deezer.com/api
+L<http://developers.deezer.com/api>
 
 =head1 AUTHOR
 
