@@ -1,6 +1,6 @@
 package WWW::Deezer::Album;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -16,6 +16,10 @@ has 'id' => (is => 'ro', isa => 'Int');
 has 'title' => (is => 'ro', isa => 'Str');
 has 'link' => (is => 'rw', isa => 'Str');
 has 'cover' => (is => 'ro', isa => 'Str');
+has 'cover_small' => (is => 'ro', isa => 'Str');
+has 'cover_medium' => (is => 'ro', isa => 'Str');
+has 'cover_big' => (is => 'ro', isa => 'Str');
+has 'cover_xl' => (is => 'ro', isa => 'Str');
 has 'genre_id' => (is => 'rw', isa => 'Int');
 has 'label' => (is => 'ro', isa => 'Str');
 has 'duration' => (is => 'ro', isa => 'Int');
@@ -23,6 +27,10 @@ has 'fans' => (is => 'ro', isa => 'Int');
 has 'rating' => (is => 'ro', isa => 'Int');
 has 'release_date' => (is => 'rw', isa => 'Str');
 has 'available' => (is => 'ro');
+has 'genres' => (is => 'ro');
+has 'nb_tracks' => (is => 'ro');
+has 'upc' => (is => 'ro', isa => 'Str');
+has 'record_type' => (is => 'ro', isa => 'Str');
 
 has 'artist' => (
     is => 'ro', 
@@ -46,14 +54,14 @@ around BUILDARGS => sub { # allow create Album object with single argument passe
     return $self;
 };
 
-around [qw/genre_id link release_date/] => sub { # add here another attributes which need fetching from server
+around [qw/genre_id link release_date upc genres nb_tracks record_type/] => sub { # add here another attributes which need fetching from server
     my ($orig, $self) = (shift, shift);
     my $attr = $self->$orig(@_);
     
     unless (defined $attr) { 
         # fetch recreate album.
         my $new_obj = $self->deezer_obj->album($self->id);
-        $attr= $new_obj->$orig(@_);
+        $attr = $new_obj->$orig(@_);
         $self->reinit_attr_values($new_obj);
     }
     
