@@ -1,11 +1,11 @@
 package WWW::Deezer::Obj;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose;
 use Moose::Util::TypeConstraints;
 
-# base class for representing Deezer objects;
+# base class for representing Deezer objects
 
 subtype 'JSONBoolean' => (as 'Int');
 
@@ -14,14 +14,16 @@ coerce 'JSONBoolean' => (
     via { JSON::is_bool($_) }
 );
 
+subtype 'Url' => as 'Str',
+    where { /^http/ };
+
 has 'deezer_obj', is => 'rw', isa => 'Ref';
 
 sub reinit_attr_values {
-    my ($self, $new) = (shift, shift);
+    my ($self, $new) = @_;
     my $package = caller || __PACKAGE__;
 
-    my $meta = $package->meta;
-    my @attrs = $meta->get_all_attributes();
+    my @attrs = $package->meta->get_all_attributes();
 
     foreach my $attr (@attrs) {
         my $name = $attr->name;
